==> openshift-model-operatorhub-6.7.0-sources.jar: io/fabric8/openshift/api/model/operatorhub/v1alpha1/CleanupSpecBuilder.java <==
package io.fabric8.openshift.api.model.operatorhub.v1alpha1;

import io.fabric8.kubernetes.api.builder.VisitableBuilder;
import java.lang.Boolean;
public class CleanupSpecBuilder extends CleanupSpecFluentImpl<CleanupSpecBuilder> implements VisitableBuilder<CleanupSpec,CleanupSpecBuilder>{
  public CleanupSpecBuilder() {
    this(false);
  }
  public CleanupSpecBuilder(Boolean validationEnabled) {
    this(new CleanupSpec(), validationEnabled);
  }
  public CleanupSpecBuilder(CleanupSpecFluent<?> fluent) {
    this(fluent, false);
  }
  public CleanupSpecBuilder(CleanupSpecFluent<?> fluent,Boolean validationEnabled) {
    this(fluent, new CleanupSpec(), validationEnabled);
  }
  public CleanupSpecBuilder(CleanupSpecFluent<?> fluent,CleanupSpec instance) {
    this(fluent, instance, false);
  }
  public CleanupSpecBuilder(CleanupSpecFluent<?> fluent,CleanupSpec instance,Boolean validationEnabled) {
    this.fluent = fluent; 
    if (instance != null) {
      fluent.withEnabled(instance.getEnabled());
      fluent.withAdditionalProperties(instance.getAdditionalProperties());
    }
    this.validationEnabled = validationEnabled; 
  }
  public CleanupSpecBuilder(CleanupSpec instance) {
    this(instance,false);
  }
  public CleanupSpecBuilder(CleanupSpec instance,Boolean validationEnabled) {
    this.fluent = this; 
    if (instance != null) {
      this.withEnabled(instance.getEnabled());
      this.withAdditionalProperties(instance.getAdditionalProperties());
    }
    this.validationEnabled = validationEnabled; 
  }
  CleanupSpecFluent<?> fluent;
  Boolean validationEnabled;
  public CleanupSpec build() {
    CleanupSpec buildable = new CleanupSpec(fluent.getEnabled());
    buildable.setAdditionalProperties(fluent.getAdditionalProperties());
    return buildable;
  }
  
}

==> openshift-model-operatorhub-6.8.1-sources.jar: io/fabric8/openshift/api/model/operatorhub/v1alpha1/CleanupSpecBuilder.java <==
package io.fabric8.openshift.api.model.operatorhub.v1alpha1;

import io.fabric8.kubernetes.api.builder.VisitableBuilder;
import java.lang.Boolean;
public class CleanupSpecBuilder extends CleanupSpecFluent<CleanupSpecBuilder> implements VisitableBuilder<CleanupSpec,CleanupSpecBuilder>{
  public CleanupSpecBuilder() {
    this(false);
  }
  public CleanupSpecBuilder(Boolean validationEnabled) {
    this(new CleanupSpec(), validationEnabled);
  }
  public CleanupSpecBuilder(CleanupSpecFluent<?> fluent) {
    this(fluent, false);
  }
  public CleanupSpecBuilder(CleanupSpecFluent<?> fluent,Boolean validationEnabled) {
    this(fluent, new CleanupSpec(), validationEnabled);
  }
  public CleanupSpecBuilder(CleanupSpecFluent<?> fluent,CleanupSpec instance) {
    this(fluent, instance, false);
  }
  public CleanupSpecBuilder(CleanupSpecFluent<?> fluent,CleanupSpec instance,Boolean validationEnabled) {
    this.fluent = fluent; 
    instance = (instance != null ? instance : new CleanupSpec());

    if (instance != null) {
      fluent.withEnabled(instance.getEnabled());
      fluent.withEnabled(instance.getEnabled());
      fluent.withAdditionalProperties(instance.getAdditionalProperties());
    }
    this.validationEnabled = validationEnabled; 
  }
  public CleanupSpecBuilder(CleanupSpec instance) {
    this(instance,false);
  }
  public CleanupSpecBuilder(CleanupSpec instance,Boolean validationEnabled) {
    this.fluent = this; 
    instance = (instance != null ? instance : new CleanupSpec());

    if (instance != null) {
      this.withEnabled(instance.getEnabled());
      this.withEnabled(instance.getEnabled());
      this.withAdditionalProperties(instance.getAdditionalProperties());
    }
    this.validationEnabled = validationEnabled; 
  }
  CleanupSpecFluent<?> fluent;
  Boolean validationEnabled;
  public CleanupSpec build() {
    CleanupSpec buildable = new CleanupSpec(fluent.getEnabled());
    buildable.setAdditionalProperties(fluent.getAdditionalProperties());
    return buildable;
  }
  
}
